@@ -30,8 +30,11 @@ qx.Class.define("callbackery.ui.Popup", {
         });
         var extraAction = {
             label : 'Cancel',
-            action : 'cancel'
+            action : 'cancel',
         };
+        if (cfg.cancelLabel) {
+            extraAction.label = cfg.cancelLabel;
+        }
         cfg.instantiationMode = 'onStartup';
         var screen = new callbackery.ui.Screen(cfg,getParentFormData,extraAction);
         this.add(screen);
